@@ -1,5 +1,42 @@
+#' A common pattern for management API parsing
+#' @param x The response
+#' @param kind The kind of response
+#' @keywords internal
+#' @noRd
+management_api_parsing <- function(x, kind){
+  assert_that(x$kind %in% kind)
+  myMessage("Fetching ", x$kind, level = 3)
+  
+  if(x$totalResults == 0){
+    myMessage("No results found")
+    return(NULL)
+  }
+  
+  if(is.null(check_empty(x$items))){
+    myMessage("No ", kind, " found ", level = 3)
+    return(NULL)
+  }
+  
+  o <- x$items %>%
+    super_flatten() %>%
+    select(-kind)
+  
+  if(!is.null(o$selfLink)){
+    o <- o %>% select(-selfLink)
+  }
+  
+  # attr only stays if no other dplyr stuff happens after this function
+  attr(o, "nextLink") <- x$nextLink
+  attr(o, "kind") <- x$kind
+  attr(o, "username") <- x$username
+  attr(o, "totalResults") <- x$totalResults
+  
+  o
+}
+
 #' ga v4 parse batching
 #' @keywords internal
+#' @noRd
 google_analytics_4_parse_batch <- function(response_list){
 
   if(!is.null(response_list$resourceQuotasRemaining)){
@@ -10,6 +47,12 @@ google_analytics_4_parse_batch <- function(response_list){
   }
   
   if(!is.null(response_list$reports)){
+    
+    if(!is.null(response_list$queryCost)){
+      myMessage("queryCost: ", 
+                response_list$queryCost, level = 3)
+    }
+    
     parsed <- lapply(response_list$reports, google_analytics_4_parse)
   } else {
     warning("No $reports found.")
@@ -41,6 +84,13 @@ google_analytics_4_parse <- function(x){
     warning("Some data has been filtered for privacy reasons.")
   }
   
+  timelr <- NULL
+  if(!is.null(x$data$dataLastRefreshed)){
+    # convert timezone to locale
+    timelr <- format(as.POSIXct(x$data$dataLastRefreshed, tz="UTC", format = "%Y-%m-%dT%H:%M:%S"), tz = Sys.timezone())
+    myMessage("API data last refreshed: ",timelr, level = 3)
+  }
+  
   dim_names <- unlist(columnHeader$dimensions)
   met_names <- unlist(lapply(columnHeader$metricHeader$metricHeaderEntries, function(x) x$name))
   met_names1 <- gsub("ga:","",met_names)
@@ -73,6 +123,10 @@ google_analytics_4_parse <- function(x){
   out <- data.frame(cbind(dims, mets),
                     stringsAsFactors = FALSE, row.names = 1:nrow(mets))
   
+  if(nrow(out) >= 1000000L){
+    warning(">1 million rows are in API response which is the API limit. Split up your API calls into smaller chunks to ensure all data is returned.")
+  }
+  
   out_names <- c(dim_names, met_names)
   out_names <- gsub("ga:","",out_names)
   names(out) <- out_names
@@ -104,6 +158,10 @@ google_analytics_4_parse <- function(x){
   attr(out, "samplingSpaceSizes") <- x$data$samplingSpaceSizes
   attr(out, "nextPageToken") <- x$nextPageToken
   
+  if(!is.null(timelr)){
+    attr(out, "dataLastRefreshed") <- timelr
+  }
+  
   assertthat::assert_that(is.data.frame(out))
   
   out
@@ -144,24 +202,35 @@ get_samplePercent <- function(sampleReadCounts, samplingSpaceSizes){
 #' @importFrom purrr map_if
 parse_ga_account_summary <- function(x){
 
-  ## hack to get rid of global variables warning
+  assert_that(x$kind == "analytics#accountSummaries")
+  
+  if(x$totalResults == 0){
+    myMessage("No results found for username:", x$username, level = 3)
+    return(NULL)
+  }
+  
+  # ## hack to get rid of global variables warning
   id <- name <- webProperties <- kind <- profiles <- NULL
-  x$items %>%
+  o <- x$items %>%
     transmute(accountId = id,
               accountName = name,
               ## fix bug if webProperties is NULL
-              webProperties = purrr::map_if(webProperties, is.null, ~ data.frame())) %>% 
+              webProperties = purrr::map_if(webProperties, is.null, ~ data.frame())) %>%
     unnest() %>% ##unnest webprops
     mutate(webPropertyId = id,
            webPropertyName = name,
            ## fix bug if profiles is NULL
-           profiles = purrr::map_if(profiles, is.null, ~ data.frame())) %>% 
-    select(-kind, -id, -name) %>% 
+           profiles = purrr::map_if(profiles, is.null, ~ data.frame())) %>%
+    select(-kind, -id, -name) %>%
     unnest() %>% ## unnest profiles
     mutate(viewId = id,
-           viewName = name) %>% 
+           viewName = name) %>%
     select(-kind, -id, -name)
   
+  attr(o, "nextLink") <- x$nextLink
+  
+  o
+  
 }
 
 
@@ -278,6 +347,6 @@ parse_google_analytics_meta <- function(x){
 
   dim_mets_attr <- x$items$attributes
 
-  data.frame(name=dim_mets, dim_mets_attr, stringsAsFactors = F)
+  data.frame(name=dim_mets, dim_mets_attr, stringsAsFactors = FALSE)
 
 }
\ No newline at end of file
